﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Reflection;
using System.Text;
using Xamarin.Forms;

namespace TemplateSelector
{
    public class FileManagerViewModel
    {
        #region Fields

        private ObservableCollection<FileManager> imageNodeInfo;

        #endregion

        #region Constructor

        public FileManagerViewModel()
        {
            GenerateSource();
        }

        #endregion

        #region Properties

        public ObservableCollection<FileManager> ImageNodeInfo
        {
            get { return imageNodeInfo; }
            set { this.imageNodeInfo = value; }
        }
        private ObservableCollection<object> checkedItems;

        public ObservableCollection<object> CheckedItems
        {
            get { return checkedItems; }
            set { this.checkedItems = value; }
        }
        public Command<object> ItemClicked { get; set; }

        #endregion

        #region Generate Source

        private void GenerateSource()
        {
            FileImageInfoRespository nodeImageInfoRepository = new FileImageInfoRespository();
            imageNodeInfo = nodeImageInfoRepository.GetNodeImageInfo();
            ItemClicked = new Command<object>(ItemClickedMethod);
        }

        private void ItemClickedMethod(object obj)
        {
            App.Current.MainPage.DisplayAlert("Message", "ItemClicked", "ok");
        }

        #endregion
    }

    public class FileImageInfoRespository
    {
        #region Constructor

        public FileImageInfoRespository()
        {
        }

        #endregion

        internal ObservableCollection<FileManager> GetNodeImageInfo()
        {
            var nodeImageInfo = new ObservableCollection<FileManager>();
            Assembly assembly = typeof(MainPage).GetTypeInfo().Assembly;

            var doc = new FileManager() { ItemName = "Documents", ImageIcon = ImageSource.FromResource("TemplateSelector.Icons.treeview_folder.png", assembly)};
            var download = new FileManager() { ItemName = "Downloads", ImageIcon = ImageSource.FromResource("TemplateSelector.Icons.treeview_folder.png", assembly) };
            var mp3 = new FileManager() { ItemName = "Music", ImageIcon = ImageSource.FromResource("TemplateSelector.Icons.treeview_folder.png", assembly) };
            var pictures = new FileManager() { ItemName = "Pictures" , ImageIcon = ImageSource.FromResource("TemplateSelector.Icons.treeview_folder.png", assembly)};
            var video = new FileManager() { ItemName = "Videos" , ImageIcon = ImageSource.FromResource("TemplateSelector.Icons.treeview_folder.png", assembly)};

            var pollution = new FileManager() { ItemName = "Environmental Pollution.docx" };
            var globalWarming = new FileManager() { ItemName = "Global Warming.ppt" };
            var sanitation = new FileManager() { ItemName = "Sanitation.docx" };
            var socialNetwork = new FileManager() { ItemName = "Social Network.pdf" };
            var youthEmpower = new FileManager() { ItemName = "Youth Empowerment.pdf" };

            var games = new FileManager() { ItemName = "Game.exe" };
            var tutorials = new FileManager() { ItemName = "Tutorials.zip" };
            var typeScript = new FileManager() { ItemName = "TypeScript.7z" };
            var uiGuide = new FileManager() { ItemName = "UI-Guide.pdf" };

            var song = new FileManager() { ItemName = "Gouttes" };

            var camera = new FileManager() { ItemName = "Camera Roll" };
            var stone = new FileManager() { ItemName = "Stone.jpg" };
            var wind = new FileManager() { ItemName = "Wind.jpg" };

            var img0 = new FileManager() { ItemName = "WIN_20160726_094117.JPG" };
            var img1 = new FileManager() { ItemName = "WIN_20160726_094118.JPG" };

            var video1 = new FileManager() { ItemName = "Naturals.mp4" };
            var video2 = new FileManager() { ItemName = "Wild.mpeg" };
            doc.SubFiles = new ObservableCollection<FileManager>
            {
                pollution,
                globalWarming,
                sanitation,
                socialNetwork,
                youthEmpower
            };

            download.SubFiles = new ObservableCollection<FileManager>
            {
                games,
                tutorials,
                typeScript,
                uiGuide
            };

            mp3.SubFiles = new ObservableCollection<FileManager>
            {
                song
            };

            pictures.SubFiles = new ObservableCollection<FileManager>
            {
                camera,
                stone,
                wind
            };
            camera.SubFiles = new ObservableCollection<FileManager>
            {
                img0,
                img1
            };

            video.SubFiles = new ObservableCollection<FileManager>
            {
                video1,
                video2
            };

            nodeImageInfo.Add(doc);
            nodeImageInfo.Add(download);
            nodeImageInfo.Add(mp3);
            nodeImageInfo.Add(pictures);
            nodeImageInfo.Add(video);
            return nodeImageInfo;
        }
    }
}
